#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 template-haskell-compat-v0208
version:              0.1.9.6
visibility:           public
id:
    template-haskell-compat-v0208-0.1.9.6-6NFLUVLULITAtTuNAJ75pM

key:
    template-haskell-compat-v0208-0.1.9.6-6NFLUVLULITAtTuNAJ75pM

license:              MIT
copyright:            (c) 2016, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:
    https://github.com/nikita-volkov/template-haskell-compat-v0208

synopsis:
    Backward-compatibility layer for Template Haskell newer than 2.8

description:
    Collection of functions that aims to help you to write
    Template Haskell that is compatible
    with all versions of GHC starting from 7.6.
    The oldest GHC serves as the common denominator here,
    so the newer functionality is avoided here.

category:             TemplateHaskell, Compatibility
abi:                  88e2e1d64f372c70c97b22c956177d2c
exposed:              True
exposed-modules:      TemplateHaskell.Compat.V0208
hidden-modules:       TemplateHaskell.Compat.V0208.Prelude
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/template-haskell-compat-v0208-0.1.9.6

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/template-haskell-compat-v0208-0.1.9.6

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/template-haskell-compat-v0208-0.1.9.6

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-template-haskell-compat-v0208
hs-libraries:
    HStemplate-haskell-compat-v0208-0.1.9.6-6NFLUVLULITAtTuNAJ75pM

depends:              base-4.18.2.1 template-haskell-2.20.0.0
haddock-interfaces:
    /usr/share/doc/haskell-template-haskell-compat-v0208/html/template-haskell-compat-v0208.haddock

haddock-html:         /usr/share/doc/haskell-template-haskell-compat-v0208/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

